@@ -56,8 +56,6 @@
 #include <mapidefs.h>
 #include <libical/ical.h>
 
-
-#include "ECIConv.h"
 /**
  * Conversion class for recurrence & exceptions (mapi <-> ical)
  */
@@ -69,7 +67,7 @@ public:
 	/* ical -> mapi */
 	HRESULT HrParseICalRecurrenceRule(TIMEZONE_STRUCT sTimeZone, icalcomponent *lpicRootEvent, icalcomponent *lpicEvent,
 									  bool bIsAllday, LPSPropTagArray lpNamedProps, icalitem *lpIcalItem);
-	HRESULT HrMakeMAPIException(icalcomponent *lpEventRoot, icalcomponent *lpicEvent, icalitem *lpIcalItem, bool blIsAllday, LPSPropTagArray lpNamedProps, ECIConv *lpIConv, icalitem::exception *lpEx);
+	HRESULT HrMakeMAPIException(icalcomponent *lpEventRoot, icalcomponent *lpicEvent, icalitem *lpIcalItem, bool bIsAllday, LPSPropTagArray lpNamedProps, std::string& strCharset, icalitem::exception *lpEx);
 	HRESULT HrMakeMAPIRecurrence(recurrence *lpRecurrence, LPSPropTagArray lpNamedProps, LPMESSAGE lpMessage);
 	bool HrValidateOccurrence(icalitem *lpItem, icalitem::exception lpEx);
 
