@@ -55,9 +55,11 @@
 #include <string>
 #include <vmime/vmime.hpp>
 #include <vmime/mailbox.hpp>
+#include "options.h"
 #include "mapidefs.h"
 #include "ECLogger.h"
-#include "options.h"
+#include "charset/convert.h"
+#include "SMIMEMessage.h"
 
 class MAPIToVMIME
 {
@@ -66,41 +68,46 @@ public:
 	MAPIToVMIME(IMAPISession *lpSession, IAddrBook *lpAddrBook, ECLogger *newlogger, sending_options sopt);
 	~MAPIToVMIME();
 
-	HRESULT convertMAPIToVMIME(IMessage *lpMessage, vmime::message** lppVMMessage, char **lppszRawSMTP = NULL);
-	string getConversionError();
+	HRESULT convertMAPIToVMIME(IMessage *lpMessage, vmime::ref<vmime::message> *lpvmMessage);
+	std::wstring getConversionError();
 
 private:
 	ECLogger *lpLogger;
-	bool delete_logger;
 	sending_options sopt;
 	LPADRBOOK m_lpAdrBook;
 	LPMAPISESSION m_lpSession;
-	string m_strError;
+	std::wstring m_strError;
+	convert_context m_converter;
+	vmime::charset m_vmCharset;
+	std::string m_strCharset;
+	std::string m_strHTMLCharset;
 
-	HRESULT fillVMIMEMail(IMessage *lpMessage, bool bSkipContent, vmime::messageBuilder* lpVMMessageBuilder, vmime::charset outgoingcharset);
+	HRESULT fillVMIMEMail(IMessage *lpMessage, bool bSkipContent, vmime::messageBuilder* lpVMMessageBuilder);
 
-	HRESULT handleTextparts(IMessage* lpMessage, vmime::messageBuilder* lpVMMessageBuilder, vmime::charset outgoingcharset, BOOL* lpbRealRTF);
-	HRESULT getMailBox(LPSRow lpRow, vmime::mailbox** lppVMMailbox, vmime::charset outgoingcharset);
-	HRESULT processRecipients(IMessage* lpMessage, vmime::messageBuilder* lpVMMessageBuilder, vmime::charset outgoingcharset);
-	HRESULT handleExtraHeaders(IMessage* lpMessage, vmime::charset& charset, vmime::header *lpVMHeader);
-	HRESULT handleReplyTo(IMessage* lpMessage, vmime::header* lpVMHeader);
-	HRESULT handleContactEntryID(ULONG cValues, LPSPropValue lpProps, string &strName, string &strType, string &strEmail);
-	HRESULT handleSenderInfo(IMessage* lpMessage, vmime::header* lpVMHeader);
+	HRESULT handleTextparts(IMessage* lpMessage, vmime::messageBuilder* lpVMMessageBuilder, BOOL* lpbRealRTF);
+	HRESULT getMailBox(LPSRow lpRow, vmime::ref<vmime::address> *lpvmMailbox);
+	HRESULT processRecipients(IMessage* lpMessage, vmime::messageBuilder* lpVMMessageBuilder);
+	HRESULT handleExtraHeaders(IMessage *lpMessage, vmime::ref<vmime::header> vmHeader);
+	HRESULT handleReplyTo(IMessage* lpMessage, vmime::ref<vmime::header> vmHeader);
+	HRESULT handleContactEntryID(ULONG cValues, LPSPropValue lpProps, std::wstring &strName, std::wstring &strType, std::wstring &strEmail);
+	HRESULT handleSenderInfo(IMessage* lpMessage, vmime::ref<vmime::header> vmHeader);
 
 	HRESULT handleAttachments(IMessage* lpMessage, vmime::messageBuilder* lpVMMessageBuilder);
 	HRESULT handleSingleAttachment(IMessage* lpMessage, LPSRow lpRow, vmime::messageBuilder* lpVMMessageBuilder);
-	HRESULT parseMimeTypeFromFilename(std::string strFilename, vmime::mediaType *lpMT, bool *lpbSendBinary);
-	HRESULT setBoundaries(vmime::header *lpVMHeader, vmime::body *lpVMBody, const std::string &boundary);
-	HRESULT handleXHeaders(IMessage* lpMessage, vmime::header *lpVMHeader);
+	HRESULT parseMimeTypeFromFilename(std::wstring strFilename, vmime::mediaType *lpMT, bool *lpbSendBinary);
+	HRESULT setBoundaries(vmime::ref<vmime::header> vmHeader, vmime::ref<vmime::body> vmBody, const std::string& boundary);
+	HRESULT handleXHeaders(IMessage* lpMessage, vmime::ref<vmime::header> vmHeader);
 	HRESULT handleTNEF(IMessage* lpMessage, vmime::messageBuilder* lpVMMessageBuilder, BOOL bRealRTF);
 
 	// build Messages
-	HRESULT BuildNoteMessage(IMessage *lpMessage, bool bSkipContent, vmime::charset& charset, vmime::message **lppVMMessage);
-	HRESULT BuildMDNMessage(IMessage *lpMessage, vmime::charset& charset, vmime::message **lppVMMessage);
+	HRESULT BuildNoteMessage(IMessage *lpMessage, bool bSkipContent, vmime::ref<vmime::message> *lpvmMessage);
+	HRESULT BuildMDNMessage(IMessage *lpMessage, vmime::ref<vmime::message> *lpvmMessage);
 
 	// util
 	void capitalize(char *s);
-	void removeEnters(char *s);
+	void removeEnters(WCHAR *s);
+	vmime::text getVmimeTextFromWide(const WCHAR* lpszwInput, bool bWrapInWord = true);
+	vmime::text getVmimeTextFromWide(const std::wstring& strwInput, bool bWrapInWord = true);
 };
 
 #endif
