@@ -112,6 +112,9 @@ private:
 	HRESULT handleHTMLTextpart(vmime::ref<vmime::header> vmHeader, vmime::ref<vmime::body> vmBody, IMessage* lpMessage, bool bAppendBody);
 	HRESULT handleAttachment(vmime::ref<vmime::header> vmHeader, vmime::ref<vmime::body> vmBody, IMessage* lpMessage, bool bAllowEmpty = true);
 	HRESULT handleMessageToMeProps(IMessage *lpMessage, LPADRLIST lpRecipients);
+
+	vmime::charset getCompatibleCharset(const vmime::charset &vmCharset);
+	std::wstring getWideFromVmimeText(const vmime::text &vmText);
 	
 	HRESULT postWriteFixups(IMessage *lpMessage);
 
