@@ -86,7 +86,7 @@ public:
 	virtual HRESULT EnumBlocks(IEnumFBBlock **ppenumfb, FILETIME ftmStart, FILETIME ftmEnd);
 	virtual HRESULT Merge(void *);
 	virtual HRESULT GetDeligateInfo(void *);
-	virtual HRESULT FindFreeBlock(LONG, LONG, LONG, BOOL, LONG, LONG, LONG, void *);
+	virtual HRESULT FindFreeBlock(LONG, LONG, LONG, BOOL, LONG, LONG, LONG, FBBlock_1 *);
 	virtual HRESULT InterSect(void *, LONG, void *);
 	virtual HRESULT SetFBRange(LONG rtmStart, LONG rtmEnd);
 	virtual HRESULT NextFBAppt(void *, ULONG, void *, ULONG, void *, void *);
@@ -106,7 +106,7 @@ public:
 			virtual HRESULT __stdcall EnumBlocks(IEnumFBBlock **ppenumfb, FILETIME ftmStart, FILETIME ftmEnd);
 			virtual HRESULT __stdcall Merge(void *);
 			virtual HRESULT __stdcall GetDeligateInfo(void *);
-			virtual HRESULT __stdcall FindFreeBlock(LONG, LONG, LONG, BOOL, LONG, LONG, LONG, void *);
+			virtual HRESULT __stdcall FindFreeBlock(LONG, LONG, LONG, BOOL, LONG, LONG, LONG, FBBlock_1 *);
 			virtual HRESULT __stdcall InterSect(void *, LONG, void *);
 			virtual HRESULT __stdcall SetFBRange(LONG rtmStart, LONG rtmEnd);
 			virtual HRESULT __stdcall NextFBAppt(void *, ULONG, void *, ULONG, void *, void *);
