@@ -47,6 +47,14 @@
  * 
  */
 
+/**
+ * @file
+ * Updates the freebusy data
+ *
+ * @addtogroup libfreebusy
+ * @{
+ */
+
 #ifndef ECFREEBUSYUPDATE_H
 #define ECFREEBUSYUPDATE_H
 
@@ -62,7 +70,10 @@
 
 #include "ECFBBlockList.h"
 
-class ECFreeBusyUpdate :	public ECUnknown
+/**
+ * Implementatie of the IFreeBusyUpdate interface
+ */
+class ECFreeBusyUpdate : public ECUnknown
 {
 private:
 	ECFreeBusyUpdate(IMessage* lpMessage);
@@ -70,7 +81,7 @@ private:
 public:
 	static HRESULT Create(IMessage* lpMessage, ECFreeBusyUpdate **lppECFreeBusyUpdate);
 	
-	virtual HRESULT QueryInterface(REFIID iid , void** ppvObject);
+	virtual HRESULT QueryInterface(REFIID refiid, void** lppInterface);
 
 	virtual HRESULT Reload();
 	virtual HRESULT PublishFreeBusy(FBBlock_1 *lpBlocks, ULONG nBlocks);
@@ -86,7 +97,7 @@ public:
 	{
 		public:
 		// From IUnknown
-		virtual HRESULT __stdcall QueryInterface(REFIID iid , void** ppvObject);
+		virtual HRESULT __stdcall QueryInterface(REFIID refiid, void** lppInterface);
 		virtual ULONG __stdcall AddRef();
 		virtual ULONG __stdcall Release();
 
@@ -103,9 +114,11 @@ public:
 	}m_xFreeBusyUpdate;
 
 private:
-	IMessage*		m_lpMessage;
-	ECFBBlockList	m_fbBlockList;
+	IMessage*		m_lpMessage; /**< Pointer to the free/busy message received from GetFreeBusyMessage */
+	ECFBBlockList	m_fbBlockList; /**< Freebusy time blocks */
 
 };
 
 #endif // ECFREEBUSYUPDATE_H
+
+/** @} */
