@@ -67,14 +67,14 @@
 
 class IExchangeManageStore : public IUnknown {
 public:
-	virtual HRESULT __stdcall CreateStoreEntryID(LPSTR lpszMsgStoreDN, LPSTR lpszMailboxDN, ULONG	ulFlags, ULONG *lpcbEntryID,
+	virtual HRESULT __stdcall CreateStoreEntryID(LPTSTR lpszMsgStoreDN, LPTSTR lpszMailboxDN, ULONG	ulFlags, ULONG *lpcbEntryID,
 												 LPENTRYID *lppEntryID) = 0;
 	virtual HRESULT __stdcall EntryIDFromSourceKey(ULONG cFolderKeySize, BYTE *lpFolderSourceKey,	ULONG cMessageKeySize,
 												   BYTE *lpMessageSourceKey, ULONG *lpcbEntryID, LPENTRYID *lppEntryID) = 0;
 	virtual HRESULT __stdcall GetRights(ULONG cbUserEntryID, LPENTRYID lpUserEntryID, ULONG cbEntryID, LPENTRYID lpEntryID,
 										ULONG *lpulRights) = 0;
-	virtual HRESULT __stdcall GetMailboxTable(LPSTR lpszServerName, LPMAPITABLE *lppTable, ULONG ulFlags) = 0;
-	virtual HRESULT __stdcall GetPublicFolderTable(LPSTR lpszServerName, LPMAPITABLE *lppTable, ULONG ulFlags) = 0;
+	virtual HRESULT __stdcall GetMailboxTable(LPTSTR lpszServerName, LPMAPITABLE *lppTable, ULONG ulFlags) = 0;
+	virtual HRESULT __stdcall GetPublicFolderTable(LPTSTR lpszServerName, LPMAPITABLE *lppTable, ULONG ulFlags) = 0;
 };
 
 typedef IExchangeManageStore* LPEXCHANGEMANAGESTORE;
@@ -147,10 +147,14 @@ typedef IExchangeManageStore* LPEXCHANGEMANAGESTORE;
 
 
 #define PR_USER_ENTRYID						PROP_TAG(PT_BINARY, pidStoreMin+0x01)
-#define PR_USER_NAME						PROP_TAG(PT_STRING8, pidStoreMin+0x02)
+#define PR_USER_NAME						PROP_TAG( PT_TSTRING, pidStoreMin+0x02)
+#define PR_USER_NAME_A						PROP_TAG( PT_STRING8, pidStoreMin+0x02)
+#define PR_USER_NAME_W						PROP_TAG( PT_UNICODE, pidStoreMin+0x02)
 
 #define PR_MAILBOX_OWNER_ENTRYID			PROP_TAG(PT_BINARY, pidStoreMin+0x03)
-#define PR_MAILBOX_OWNER_NAME				PROP_TAG(PT_STRING8, pidStoreMin+0x04)
+#define PR_MAILBOX_OWNER_NAME				PROP_TAG( PT_TSTRING, pidStoreMin+0x04)
+#define PR_MAILBOX_OWNER_NAME_A				PROP_TAG( PT_STRING8, pidStoreMin+0x04)
+#define PR_MAILBOX_OWNER_NAME_W				PROP_TAG( PT_UNICODE, pidStoreMin+0x04)
 #define PR_OOF_STATE						PROP_TAG(PT_BOOLEAN, pidStoreMin+0x05)
 
 #define PR_HIERARCHY_SERVER					PROP_TAG(PT_TSTRING, pidStoreMin+0x1B)
@@ -261,10 +265,16 @@ typedef IExchangeManageStore* LPEXCHANGEMANAGESTORE;
 #define PR_HAS_NAMED_PROPERTIES				PROP_TAG(PT_BOOLEAN, pidMessageReadOnlyMin+0x0A)
 
 #define PR_CREATOR_NAME						PROP_TAG(PT_TSTRING, pidExchangeXmitReservedMin+0x18)
+#define PR_CREATOR_NAME_A					PROP_TAG(PT_STRING8, pidExchangeXmitReservedMin+0x18)
+#define PR_CREATOR_NAME_W					PROP_TAG(PT_UNICODE, pidExchangeXmitReservedMin+0x18)
 #define PR_CREATOR_ENTRYID					PROP_TAG(PT_BINARY, pidExchangeXmitReservedMin+0x19)
 #define PR_LAST_MODIFIER_NAME				PROP_TAG(PT_TSTRING, pidExchangeXmitReservedMin+0x1A)
+#define PR_LAST_MODIFIER_NAME_A				PROP_TAG(PT_STRING8, pidExchangeXmitReservedMin+0x1A)
+#define PR_LAST_MODIFIER_NAME_W				PROP_TAG(PT_UNICODE, pidExchangeXmitReservedMin+0x1A)
 #define PR_LAST_MODIFIER_ENTRYID			PROP_TAG(PT_BINARY, pidExchangeXmitReservedMin+0x1B)
-#define PR_REPLY_RECIPIENT_SMTP_PROXIES 	PROP_TAG(PT_TSTRING, pidExchangeXmitReservedMin+0x1C)
+#define PR_REPLY_RECIPIENT_SMTP_PROXIES		PROP_TAG(PT_TSTRING, pidExchangeXmitReservedMin+0x1C)
+#define PR_REPLY_RECIPIENT_SMTP_PROXIES_A	PROP_TAG(PT_STRING8, pidExchangeXmitReservedMin+0x1C)
+#define PR_REPLY_RECIPIENT_SMTP_PROXIES_W	PROP_TAG(PT_UNICODE, pidExchangeXmitReservedMin+0x1C)
 
 #define PR_HAS_DAMS							PROP_TAG(PT_BOOLEAN, pidExchangeXmitReservedMin+0x0A)
 #define PR_RULE_TRIGGER_HISTORY				PROP_TAG(PT_BINARY, pidExchangeXmitReservedMin+0x12)
