@@ -222,15 +222,15 @@ typedef struct _s_MAPIUID {
 #ifdef  UNICODE
 #define PT_TSTRING          PT_UNICODE
 #define PT_MV_TSTRING       (MV_FLAG|PT_UNICODE)
-/* #define LPSZ                lpszW */
-/* #define LPPSZ               lppszW */
-/* #define MVSZ                MVszW */
+#define LPSZ                lpszW
+#define LPPSZ               lppszW
+#define MVSZ                MVszW
 #else
 #define PT_TSTRING          PT_STRING8
 #define PT_MV_TSTRING       (MV_FLAG|PT_STRING8)
-/* #define LPSZ                lpszA */
-/* #define LPPSZ               lppszA */
-/* #define MVSZ                MVszA */
+#define LPSZ                lpszA
+#define LPPSZ               lppszA
+#define MVSZ                MVszA
 #endif
 
 
