@@ -216,12 +216,13 @@ public:
 		return er;
 	}
 
-	ECRESULT GetCacheRange(const key_type &key, std::list<typename _MapType::value_type> *values)
+	ECRESULT GetCacheRange(const key_type &lower, const key_type &upper, std::list<typename _MapType::value_type> *values)
 	{
 		typedef typename _MapType::iterator iterator;
 
-		std::pair<iterator,iterator> piiResult = m_map.equal_range(key);
-		for (iterator i = piiResult.first; i != piiResult.second; ++i)
+		iterator iLower = m_map.lower_bound(lower);
+		iterator iUpper = m_map.upper_bound(upper);
+		for (iterator i = iLower; i != iUpper; ++i)
 			values->push_back(*i);
 
 		return erSuccess;
