@@ -55,6 +55,8 @@
 #include <openssl/ssl.h>
 #include <openssl/err.h>
 
+#include <string>
+
 #include "ECConfig.h"
 #include "ECLogger.h"
 
@@ -76,7 +78,7 @@ public:
 	HRESULT HrReadLine(std::string * strBuffer);
 	HRESULT HrWriteString(char * szBuffer);
 	HRESULT HrWriteString(const std::string & strBuffer);
-	HRESULT HrWriteLine(char *szBuffer);
+	HRESULT HrWriteLine(char *szBuffer, int len = 0);
 	HRESULT HrWriteLine(const std::string & strBuffer);
 	HRESULT HrReadBytes(char *szBuffer, ULONG ulByteCount);
 	HRESULT HrReadBytes(std::string * strBuffer, ULONG ulByteCount);
@@ -97,7 +99,7 @@ private:
 	int fd;
 	SSL *lpSSL;
 	static SSL_CTX *lpCTX;
-	string strIP;
+	std::string strIP;
 
 	char *fd_gets(char *buf, int *lpulLen);
 	char *SSL_gets(char *buf, int *lpulLen);
