@@ -77,11 +77,13 @@ static const char *lpszDEFAULTDIRECTIVES[] = { "include", NULL };
 class ECConfig {
 public:
 	static ECConfig* Create(const configsetting_t *lpDefaults, const char **lpszDirectives = lpszDEFAULTDIRECTIVES);
+	static const char* GetDefaultPath(const char* lpszBasename);
 
 	virtual ~ECConfig();
 
 	virtual bool	LoadSettings(const char *szFilename) = 0;
 	virtual bool	LoadSettings(const wchar_t *szFilename);
+	virtual const char*	GetSettingsPath() = 0;
 	virtual bool	ReloadSettings() = 0;
 
 	virtual bool	AddSetting(const char *szName, const char *szValue, const unsigned int ulGroup = 0) = 0;
