@@ -229,3 +229,20 @@ HRESULT __stdcall CLASSMETHOD(_class, CLASSMETHOD(XCLASS(_iface), _method))(ARGL
 		_trace(TRACE_RETURN, METHODSTR(_iface, _method), "SUCCESS: " FORMAT_ARGS(__VA_ARGS__), PRINT_ARGS_OUT(__VA_ARGS__));	\
 	return hr;																									\
 }
+
+#define DEF_HRMETHOD_FORWARD(_trace, _class, _iface, _method, _member, ...)														\
+HRESULT __stdcall CLASSMETHOD(_class, _method)(ARGLIST(__VA_ARGS__))	{			\
+	_trace(TRACE_ENTRY, METHODSTR(_iface, _method), FORMAT_ARGS(__VA_ARGS__), PRINT_ARGS_IN( __VA_ARGS__));			\
+	HRESULT	hr = hrSuccess;																						\
+	try {																										\
+		hr = _member->_method(ARGS(__VA_ARGS__));																	\
+	} catch (const std::bad_alloc &) {																			\
+		hr = MAPI_E_NOT_ENOUGH_MEMORY;																			\
+	}																											\
+	if (FAILED(hr))																								\
+		_trace(TRACE_RETURN, METHODSTR(_iface, _method), "FAILED: %s", GetMAPIErrorDescription(hr).c_str());	\
+	else																										\
+		_trace(TRACE_RETURN, METHODSTR(_iface, _method), "SUCCESS: " FORMAT_ARGS(__VA_ARGS__), PRINT_ARGS_OUT(__VA_ARGS__));	\
+	return hr;																									\
+}
+
