@@ -82,6 +82,11 @@
 #define TSTRING_PRINTF "%s"
 #endif
 
+  #define SIZE_T_PRINTF    "%lu"
+  #define SSIZE_T_PRINTF   "%l"
+  #define PTRDIFF_T_PRINTF "%l"
+
+
 /**
  * Prefixes in log message in different process models.
  *
@@ -97,7 +102,7 @@ enum logprefix { LP_NONE, LP_TID, LP_PID };
  */
 class ECLogger {
 private:
-	int m_ulRef;
+	unsigned m_ulRef;
 
 protected:
 	/**
@@ -152,12 +157,12 @@ public:
 	/** 
 	 * Adds reference to this object
 	 */
-	void AddRef();
+	unsigned AddRef();
 	/** 
 	 * Removes a reference from this object, and deletes it if all
 	 * references are removed.
 	 */
-	void Release();
+	unsigned Release();
 	/**
 	 * Used for log rotation. Implementations should prepare to log in a new log.
 	 *
@@ -290,6 +295,7 @@ public:
 	virtual void LogVA(int loglevel, const char *format, va_list& va);
 
 	int GetFileDescriptor();
+	void Disown();
 };
 
 ECLogger* StartLoggerProcess(ECConfig *lpConfig, ECLogger *lpFileLogger);
