@@ -70,10 +70,6 @@
 #define PR_EC_SSLKEY_PASS				PROP_TAG(PT_STRING8,	PR_EC_BASE+0x06)
 #define PR_EC_LAST_CONNECTIONTYPE		PROP_TAG(PT_LONG,		PR_EC_BASE+0x09)
 #define PR_EC_CONNECTION_TIMEOUT		PROP_TAG(PT_LONG,		PR_EC_BASE+0x0A)
-#define PR_EC_MSEMS_EMU					PROP_TAG(PT_BOOLEAN,	PR_EC_BASE+0x0B)
-#define PR_EC_OFFLINE_PATH				PROP_TAG(PT_TSTRING,	PR_EC_BASE+0x10) /* same as PR_EC_CONTACT_ENTRYID, but on different objects! */
-#define PR_EC_OFFLINE_PATH_A			PROP_TAG(PT_STRING8,	PR_EC_BASE+0x10) /* same as PR_EC_CONTACT_ENTRYID, but on different objects! */
-#define PR_EC_OFFLINE_PATH_W			PROP_TAG(PT_UNICODE,	PR_EC_BASE+0x10) /* same as PR_EC_CONTACT_ENTRYID, but on different objects! */
 
 // Used for proxy settings
 #define PR_EC_PROXY_HOST				PROP_TAG(PT_STRING8,	PR_EC_BASE+0x0B)
@@ -82,6 +78,13 @@
 #define PR_EC_PROXY_PASSWORD			PROP_TAG(PT_STRING8,	PR_EC_BASE+0x0E)
 #define PR_EC_PROXY_FLAGS				PROP_TAG(PT_LONG,		PR_EC_BASE+0x0F)
 
+#define PR_EC_OFFLINE_PATH				PROP_TAG(PT_TSTRING,	PR_EC_BASE+0x10) /* same as PR_EC_CONTACT_ENTRYID, but on different objects! */
+#define PR_EC_OFFLINE_PATH_A			PROP_TAG(PT_STRING8,	PR_EC_BASE+0x10) /* same as PR_EC_CONTACT_ENTRYID, but on different objects! */
+#define PR_EC_OFFLINE_PATH_W			PROP_TAG(PT_UNICODE,	PR_EC_BASE+0x10) /* same as PR_EC_CONTACT_ENTRYID, but on different objects! */
+
+#define PR_EC_SERVERNAME				PROP_TAG(PT_TSTRING,	PR_EC_BASE+0x11) /* same as PR_EC_HIERARCHYID, but on archive store profile sections! */
+#define PR_EC_SERVERNAME_A				PROP_TAG(PT_STRING8,	PR_EC_BASE+0x11) /* same as PR_EC_HIERARCHYID, but on archive store profile sections! */
+#define PR_EC_SERVERNAME_W				PROP_TAG(PT_UNICODE,	PR_EC_BASE+0x11) /* same as PR_EC_HIERARCHYID, but on archive store profile sections! */
 
 ////////////////////////////////////////////////////////////////////////////////
 
@@ -91,6 +94,7 @@
 #define PR_EC_STOREGUID					PROP_TAG(PT_BINARY,		PR_EC_BASE+0x12)
 /* 0x6712 == PR_RANK (edkmdb.h) */
 #define PR_EC_COMPANYID					PROP_TAG(PT_LONG,		PR_EC_BASE+0x13)
+#define PR_EC_STORETYPE					PROP_TAG(PT_LONG,		PR_EC_BASE+0x14)
 
 #define PR_EC_QUOTA_MAIL_TIME			PROP_TAG(PT_SYSTIME,	PR_EC_BASE+0x20)
 //NOTE:	The properties PR_QUOTA_WARNING_THRESHOLD, PR_QUOTA_SEND_THRESHOLD, PR_QUOTA_RECEIVE_THRESHOLD
@@ -191,6 +195,12 @@
 #define PR_EC_HOMESERVER_NAME_W			PROP_TAG(PT_UNICODE,	PR_EC_BASE+0xC1)
 #define PR_EC_SERVER_UID				PROP_TAG(PT_BINARY,		PR_EC_BASE+0xC2)
 #define PR_EC_DELETED_STORE				PROP_TAG(PT_BOOLEAN,	PR_EC_BASE+0xC3)
+#define PR_EC_ARCHIVE_SERVERS			PROP_TAG(PT_MV_TSTRING,	PR_EC_BASE+0xC4)
+#define PR_EC_ARCHIVE_SERVERS_A			PROP_TAG(PT_MV_STRING8,	PR_EC_BASE+0xC4)
+#define PR_EC_ARCHIVE_SERVERS_W			PROP_TAG(PT_MV_UNICODE,	PR_EC_BASE+0xC4)
+#define PR_EC_ARCHIVE_COUPLINGS			PROP_TAG(PT_MV_TSTRING,	PR_EC_BASE+0xC5)
+#define PR_EC_ARCHIVE_COUPLINGS_A		PROP_TAG(PT_MV_STRING8,	PR_EC_BASE+0xC5)
+#define PR_EC_ARCHIVE_COUPLINGS_W		PROP_TAG(PT_MV_UNICODE,	PR_EC_BASE+0xC5)
 
 #define PR_EC_SEARCHFOLDER_STATUS		PROP_TAG(PT_LONG,	PR_EC_BASE+0x90)
 
@@ -200,6 +210,7 @@
 #define PR_EC_SYNC_WAIT_TIME			PROP_TAG(PT_LONG,	PR_EC_BASE+0xA3)
 #define PR_EC_SYNC_ON_NOTIFY			PROP_TAG(PT_LONG,	PR_EC_BASE+0xA4)
 #define PR_EC_RESYNC_ID					PROP_TAG(PT_LONG,	PR_EC_BASE+0xA5)
+#define PR_EC_STORED_SERVER_UID			PROP_TAG(PT_BINARY,	PR_EC_BASE+0xA6)
 
 
 // Properties for IMailUsers
@@ -216,6 +227,9 @@
 
 #define PR_EC_PUBLIC_IPM_SUBTREE_ENTRYID	PROP_TAG(PT_BINARY,	PR_EC_BASE+0xD0)
 
+// Special WA properties used between zarafa-dagent and WA
+#define PR_EC_WA_ATTACHMENT_HIDDEN_OVERRIDE	PROP_TAG(PT_BOOLEAN,PR_EC_BASE+0xE0)
+
 // Flags for PR_EC_FLAGS
 #define EC_PROFILE_FLAGS_NO_NOTIFICATIONS		0x0000001
 #define EC_PROFILE_FLAGS_NO_COMPRESSION			0x0000002
@@ -238,6 +252,16 @@
 // Type of store
 #define ECSTORE_TYPE_PRIVATE	0
 #define ECSTORE_TYPE_PUBLIC		1
+#define ECSTORE_TYPE_ARCHIVE	2
+
+#define ECSTORE_TYPE_MASK_PRIVATE (1 << ECSTORE_TYPE_PRIVATE)
+#define ECSTORE_TYPE_MASK_PUBLIC (1 << ECSTORE_TYPE_PUBLIC)
+#define ECSTORE_TYPE_MASK_ARCHIVE (1 << ECSTORE_TYPE_ARCHIVE)
+
+#define ECSTORE_TYPE_ISVALID(ulStoreType)		\
+	((ulStoreType) == ECSTORE_TYPE_PRIVATE ||	\
+	 (ulStoreType) == ECSTORE_TYPE_PUBLIC ||	\
+	 (ulStoreType) == ECSTORE_TYPE_ARCHIVE)
 
 // Flags for IECServiceAdmin::PurgeCache()
 #define PURGE_CACHE_QUOTA			0x0001
