@@ -53,7 +53,7 @@
 enum SCName {
 	/* server stats */
 	SCN_SERVER_STARTTIME, SCN_SERVER_LAST_CACHECLEARED, SCN_SERVER_LAST_CONFIGRELOAD,
-	SCN_SERVER_CONNECTIONS, SCN_MAX_SOCKET_NUMBER, SCN_REDIRECT_COUNT,
+	SCN_SERVER_CONNECTIONS, SCN_MAX_SOCKET_NUMBER, SCN_REDIRECT_COUNT, SCN_SOAP_REQUESTS, SCN_RESPONSE_TIME, SCN_PROCESSING_TIME, 
 	/* search folder stats */
 	SCN_SEARCHFOLDER_COUNT, SCN_SEARCHFOLDER_THREADS,
 	/* database stats */
