@@ -51,6 +51,7 @@
 #define UTIL_H
 
 #include "edkmdb.h"
+#include <mapix.h>
 #include <string>
 
 #include "ECDefs.h"
@@ -77,6 +78,7 @@ public:
 	static HRESULT	HrCopySRowSet(LPSRowSet lpDest, LPSRowSet lpSrc, void *lpBase);
 	static HRESULT	HrCopySRow(LPSRow lpDest, LPSRow lpSrc, void *lpBase);
 
+	static HRESULT	HrCopyPropTagArray(LPSPropTagArray lpSrc, LPSPropTagArray *lppDest);
 	static HRESULT	HrCopyUnicodePropTagArray(ULONG ulFlags, LPSPropTagArray lpSrc, LPSPropTagArray *lppDest);
 
 	static HRESULT	HrCopyBinary(ULONG ulSize, LPBYTE lpSrc, ULONG *lpulDestSize, LPBYTE *lppDest, LPVOID lpBase = NULL);
@@ -102,7 +104,9 @@ public:
 	static HRESULT	HrHtmlToRtf(IStream *html, IStream *rtf, unsigned int ulCodepage);
 	static HRESULT	HrHtmlToRtf(const WCHAR *lpwHTML, std::string& strRTF);
 
-	static LPCTSTR	HrMAPIErrorToText(HRESULT hr);
+	static ULONG GetBestBody(IMAPIProp *lpPropObj, ULONG ulFlags);
+
+	static HRESULT HrMAPIErrorToText(HRESULT hr, LPTSTR *lppszError, void *lpBase = NULL);
 
 	static bool ValidatePropTagArray(LPSPropTagArray lpPropTagArray);
 
@@ -158,6 +162,10 @@ public:
 	static HRESULT HrDeleteAttachments(LPMESSAGE lpMsg);
 	static HRESULT HrDeleteRecipients(LPMESSAGE lpMsg);
 
+	static HRESULT HrDeleteMessage(IMAPISession *lpSession, IMessage *lpMessage);
+
+	static bool FHasHTML(IMAPIProp *lpProp);
+
 	struct SBinaryLess {
 		bool operator()(const SBinary &left, const SBinary &right) const {
 			return CompareSBinary(left, right) < 0;
