@@ -100,6 +100,8 @@
 #define ZARAFA_E_BUSY					MAKE_ZARAFA_E( 43 )
 #define ZARAFA_E_OBJECT_DELETED			MAKE_ZARAFA_E( 44 )
 #define ZARAFA_E_USER_CANCEL			MAKE_ZARAFA_E( 45 )
+#define ZARAFA_E_UNKNOWN_FLAGS			MAKE_ZARAFA_E( 46 )
+#define ZARAFA_E_SUBMITTED				MAKE_ZARAFA_E( 47 )
 
 #define erSuccess	ZARAFA_E_NONE
 
