@@ -52,6 +52,7 @@
 
 #include <stdexcept>
 #include <mapiutil.h>
+#include "Util.h"
 
 class mapi_rowset_ptr
 {
@@ -65,11 +66,40 @@ public:
 	mapi_rowset_ptr(): m_lpsRowSet(NULL) {}
 	mapi_rowset_ptr(LPSRowSet lpsRowSet): m_lpsRowSet(lpsRowSet) {}
 
+	mapi_rowset_ptr(const mapi_rowset_ptr &other): m_lpsRowSet(NULL) {
+		if (other.m_lpsRowSet) {
+			MAPIAllocateBuffer(CbNewSRowSet(other.m_lpsRowSet->cRows), (LPVOID*)&m_lpsRowSet);
+			Util::HrCopySRowSet(m_lpsRowSet, other.m_lpsRowSet, m_lpsRowSet);
+		}
+	}
+
+	mapi_rowset_ptr& operator=(const mapi_rowset_ptr &other) {
+		if (&other != this) {
+			if (m_lpsRowSet)
+				FreeProws(m_lpsRowSet);
+			
+			if (other.m_lpsRowSet) {
+				MAPIAllocateBuffer(CbNewSRowSet(other.m_lpsRowSet->cRows), (LPVOID*)&m_lpsRowSet);
+				Util::HrCopySRowSet(m_lpsRowSet, other.m_lpsRowSet, m_lpsRowSet);
+			} else
+				m_lpsRowSet = NULL;
+		}
+
+		return *this;
+	}
+
 	~mapi_rowset_ptr() {
 		if (m_lpsRowSet)
 			FreeProws(m_lpsRowSet);
 	}
 
+	void reset(LPSRowSet lpsRowSet = NULL) {
+		if (m_lpsRowSet)
+			FreeProws(m_lpsRowSet);
+
+		m_lpsRowSet = lpsRowSet;
+	}
+
 	LPSRowSet* operator&() {
 		if (m_lpsRowSet) {
 			FreeProws(m_lpsRowSet);
@@ -102,10 +132,6 @@ public:
 
 private:
 	LPSRowSet	m_lpsRowSet;
-
-private:
-	mapi_rowset_ptr(const mapi_rowset_ptr&);
-	mapi_rowset_ptr& operator=(const mapi_rowset_ptr&);
 };
 
 #endif // ndef mapi_rowset_ptr_INCLUDED
