@@ -798,4 +798,33 @@ PR_ADDITIONAL_REN_ENTRYIDS:
 
 #define PR_AB_CHOOSE_DIRECTORY_AUTOMATICALLY PROP_TAG( PT_BOOLEAN, 0x3D1C)
 
+#define PR_STORE_UNICODE_MASK	PROP_TAG(PT_LONG, 0x340f)
+
+#define PR_PROCESS_MEETING_REQUESTS				PROP_TAG(PT_BOOLEAN, 0x686d)
+#define PR_DECLINE_CONFLICTING_MEETING_REQUESTS	PROP_TAG(PT_BOOLEAN, 0x686f)
+#define PR_DECLINE_RECURRING_MEETING_REQUESTS	PROP_TAG(PT_BOOLEAN, 0x686e)
+
+#ifndef PR_FREEBUSY_ENTRYIDS
+#define PR_FREEBUSY_ENTRYIDS PROP_TAG(PT_MV_BINARY, 0x36e4)
+#endif
+
+#ifndef PR_FREEBUSY_NUM_MONTHS
+#define PR_FREEBUSY_NUM_MONTHS PROP_TAG(PT_LONG, 0x6841)
+#endif
+
+// Notify long term entryid, do not use this!
+#define fnevLongTermEntryIDs ((ULONG) 0x20000000)
+
+#define PERSIST_SENTINEL 			0x0000
+#define RSF_PID_RSS_SUBSCRIPTION	0x8001
+#define RSF_PID_SEND_AND_TRACK		0x8002
+#define RSF_PID_TODO_SEARCH			0x8004
+#define RSF_PID_CONV_ACTIONS		0x8006
+#define RSF_PID_COMBINED_ACTIONS	0x8007
+#define RSF_PID_SUGGESTED_CONTACTS	0x8008
+
+#define RSF_ELID_HEADER				0x0002
+#define RSF_ELID_ENTRYID			0x0001
+#define ELEMENT_SENTINEL			0x0000
+
 #endif
