@@ -140,17 +140,23 @@ unsigned char x2b(char c);
 std::string hex2bin(const std::string &input);
 std::string hex2bin(const std::wstring &input);
 
+std::string bin2hex(const std::string &input);
+std::wstring bin2hexw(const std::string &input);
+
 std::string bin2hex(unsigned int inLength, const unsigned char *input);
 std::wstring bin2hexw(unsigned int inLength, const unsigned char *input);
+
 #ifdef UNICODE
 #define bin2hext bin2hexw
 #else
 #define bin2hext bin2hex
 #endif
 
-std::string StringEscape(const char* input, const char *tokens, const char escape);
+std::string urlEncode(const std::string &input);
+std::wstring urlEncode(const std::wstring &input);
+std::string urlDecode(const std::string &input);
 
-std::string strUnEscapeHex(std::string strIn);
+std::string StringEscape(const char* input, const char *tokens, const char escape);
 
 template<typename T>
 std::vector<T> tokenize(const T &str, const T &delimiters)
