@@ -54,7 +54,7 @@
 
 class CPthreadMutex {
 public:
-	CPthreadMutex();
+	CPthreadMutex(bool bRecurse = false);
 	~CPthreadMutex();
 
 	void Lock();
@@ -83,4 +83,27 @@ private:
 	pthread_mutex_t &m_mutex;
 };
 
+
+template<int(*fnlock)(pthread_rwlock_t*)>
+class scoped_rwlock {
+public:
+	scoped_rwlock(pthread_rwlock_t &rwlock) : m_rwlock(rwlock) {
+		fnlock(&m_rwlock);
+	}
+
+	~scoped_rwlock() { 
+		pthread_rwlock_unlock(&m_rwlock);
+	}
+
+private:
+	// Make sure an object is not accidentally copied
+	scoped_rwlock(const scoped_rwlock &);
+	scoped_rwlock& operator=(const scoped_rwlock &);
+
+	pthread_rwlock_t &m_rwlock;
+};
+
+typedef scoped_rwlock<pthread_rwlock_wrlock> scoped_exclusive_rwlock;
+typedef scoped_rwlock<pthread_rwlock_rdlock> scoped_shared_rwlock;
+
 #endif //#ifndef ECTHREADUTIL_H
