@@ -9,6 +9,8 @@ else:
     PT_TSTRING		= PT_STRING8;
     PT_MV_TSTRING	= PT_MV_STRING8;
 
+PR_NULL = PROP_TAG( PT_NULL, 0x0000)
+
 # Default properties
 PR_ACKNOWLEDGEMENT_MODE = PROP_TAG( PT_LONG,      0x0001)
 PR_ALTERNATE_RECIPIENT_ALLOWED = PROP_TAG( PT_BOOLEAN,   0x0002)
@@ -1350,6 +1352,8 @@ PR_EC_FLAGS				= PROP_TAG(PT_LONG, PR_EC_BASE + 0x04)
 PR_EC_SSLKEY_FILE		= PROP_TAG(PT_STRING8, PR_EC_BASE + 0x05)
 PR_EC_SSLKEY_PASS		= PROP_TAG(PT_STRING8, PR_EC_BASE + 0x06)
 
+PR_EC_STOREGUID         =  PROP_TAG(PT_BINARY, PR_EC_BASE+0x12)
+
 PR_EC_CHANGE_ADVISOR	= PROP_TAG(PT_OBJECT, PR_EC_BASE+0x89)
 
 PR_EC_STATSTABLE_SYSTEM		= PROP_TAG(PT_OBJECT,		PR_EC_BASE+0x30)
@@ -1392,6 +1396,14 @@ PR_EC_DISABLED_FEATURES   = PROP_TAG(PT_MV_TSTRING, PR_EC_BASE+0xB4)
 PR_EC_DISABLED_FEATURES_A = PROP_TAG(PT_MV_STRING8, PR_EC_BASE+0xB4)
 PR_EC_DISABLED_FEATURES_W = PROP_TAG(PT_MV_UNICODE, PR_EC_BASE+0xB4)
 
+PR_EC_ARCHIVE_SERVERS		= PROP_TAG(PT_MV_TSTRING,	PR_EC_BASE+0xC4)
+PR_EC_ARCHIVE_SERVERS_A		= PROP_TAG(PT_MV_STRING8,	PR_EC_BASE+0xC4)
+PR_EC_ARCHIVE_SERVERS_W		= PROP_TAG(PT_MV_UNICODE,	PR_EC_BASE+0xC4)
+PR_EC_ARCHIVE_COUPLINGS		= PROP_TAG(PT_MV_TSTRING,	PR_EC_BASE+0xC5)
+PR_EC_ARCHIVE_COUPLINGS_A	= PROP_TAG(PT_MV_STRING8,	PR_EC_BASE+0xC5)
+PR_EC_ARCHIVE_COUPLINGS_W	= PROP_TAG(PT_MV_UNICODE,	PR_EC_BASE+0xC5)
+
+
 # Flags for PR_EC_FLAGS
 EC_PROFILE_FLAGS_NO_NOTIFICATIONS		= 0x0000001
 EC_PROFILE_FLAGS_NO_COMPRESSION			= 0x0000002
