@@ -16,9 +16,9 @@ if [ ! -d "${ZARAFA_USER_SCRIPTS}" ] ; then
     exit 1
 fi
 
-if [ -z "${ZARAFA_USER}" -a -z "${ZARAFA_STOREID}" ] ; then
+if [ -z "${ZARAFA_USER}" -a -z "${ZARAFA_STOREGUID}" ] ; then
     exec >&2
-    echo "ZARAFA_USER and ZARAFA_STOREID is not set."
+    echo "ZARAFA_USER and ZARAFA_STOREGUID is not set."
     exit 1
 fi
 
